@@ -30,21 +30,19 @@ psi_summary = function(date = "") {
   URL = parse_api_date(api = "environment/psi",
                        input_date = date,
                        summary = TRUE)
-
-  if (curl::has_internet()) {
-    output = httr::GET(URL)
-  } else {
-    message("No internet connection found.")
-    return(NULL)
-  }
+  output = httr::GET(URL)
 
   # Error check
   content.output = parse_api_output(output)
 
-  if (length(content.output$items) == 0) {
-    stop("No data returned from API.")
+  if (length(content.output$items) == 0 || length(content.output$items) == 1) {
+    return("No data returned from API.")
   }
 
+  #if (content.output$api_info$message == "No recent updates from the agency.") {
+  #  stop("No data returned from API.")
+  #}
+
   # Extracting Data Frame
 
   psi_summary = lapply(1:length(content.output$items), function(x) {
